==> kdevplatform-1.7.0.tar.xz: kdevplatform-1.7.0/plugins/vcschangesview/kdevvcschangesview.desktop.cmake <==
[Desktop Entry]
Type=Service
Comment=This plugin provides integration between the projects and their VCS infrastructure
Comment[bs]=Ovaj dodatak omogućava integraciju između projekata i njihove VCS infrakstrukture
Comment[ca]=Aquest connector proporciona la integració entre els projectes i la seva infraestructura de VCS
Comment[ca@valencia]=Este connector proporciona la integració entre els projectes i la seua infraestructura de VCS
Comment[da]=Dette plugin giver integration mellem projekterne og deres VCS-infrastruktur
Comment[de]=Dieses Modul stellt eine Integration zwischen Projekten und ihrer VCS-Infrastruktur her.
Comment[el]=Το πρόσθετο αυτό παρέχει ολοκλήρωση ανάμεσα στα έργα και της VCS υποδομής τους
Comment[en_GB]=This plugin provides integration between the projects and their VCS infrastructure
Comment[es]=Este complemento proporciona integración entre los proyectos y su infraestructura VCS
Comment[et]=See plugin võimaldab lõimida projektid ja nende versioonihalduse infrastruktuuri
Comment[fi]=Tämä liitännäinen tarjoaa projektien ja niiden versionhallintajärjestelmien välisen integraation
Comment[fr]=Ce module externe fournit une intégration entre les projets et leur infrastructure VCS
Comment[gl]=Este complemento fornece integración entre os proxectos e a súa infraestrutura VCS
Comment[hu]=Ez a bővítmény integrációt biztosít a projektek és azok VCS infrastruktúrája között
Comment[it]=Questa estensione fornisce integrazione tra i progetti e la loro infrastruttura VCS
Comment[kk]=Бұл плагині жоба мен оның нұсқаларын қадағалау жүйесімен біріктіруін қамтамасыз етеді.
Comment[nb]=Dette programtillegget gir integrering mellom prosjektene og deres VCS infrastruktur
Comment[nds]=Mit dit Moduul laat sik Projekten un ehr VKS-Infrastruktuur inbinnen.
Comment[nl]=Deze plugin geeft integratie tussen de projecten en hun VCS-infrastructuur
Comment[pl]=Wtyczka ta zapewnia integracje pomiędzy projektami i ich infrastrukturą systemu kontroli wersji (VCS)
Comment[pt]=Este 'plugin' oferece a integração entre os projectos e a sua infra-estrutura de SCV
Comment[pt_BR]=Este plugin fornece a integração entre os projetos e sua infraestrutura de VCS
Comment[ru]=Это расширение обеспечивает интеграцию проектов с инфраструктурой VCS
Comment[sk]=Tento plugin poskytuje integráciu medzi projektami a ich VCS infraštruktúrou
Comment[sl]=Ta vstavek ponuja most med projekti in njihovo infrastrukturo nadzora različic
Comment[sv]=Det här insticksprogrammet tillhandahåller integrering mellan projekten och deras VCS infrastruktur
Comment[tr]=Bu eklenti, projeler ile projelerin sürüm kontrol sistemi altyapıları arasında bütünleşme sağlar
Comment[uk]=Цей додаток забезпечує інтеграцію між проектами та їхньою структурою системи керування версіями
Comment[x-test]=xxThis plugin provides integration between the projects and their VCS infrastructurexx
Comment[zh_CN]=此插件提供工程和它们的代码管理系统的集成
Comment[zh_TW]=此外掛程式提供專案與它們之間版本控制系統基礎間的整合
Name=VCS Integration
Name[bs]=VCS Integracija
Name[ca]=Integració de VCS
Name[ca@valencia]=Integració de VCS
Name[da]=VCS-integration
Name[de]=VCS-Integration
Name[el]=VCS ολοκλήρωση
Name[en_GB]=VCS Integration
Name[es]=Integración VCS
Name[et]=Versioonihalduse lõimimine
Name[fi]=VCS-integraatio
Name[fr]=Intégration de VCS
Name[gl]=Integración con VCS
Name[hu]=VCS integráció
Name[it]=Integrazione VCS
Name[kk]=Нұсқаларын қадағалау жүйесімен біріктіру 
Name[nb]=VCS-integrering
Name[nds]=VKS-Inbinnen
Name[nl]=VCS-integratie
Name[pl]=Integracja VCS
Name[pt]=Integração com o SCV
Name[pt_BR]=Integração com o VCS
Name[ru]=Интеграция VCS
Name[sk]=Integrácia VCS
Name[sl]=Vgradnja nadzora različic
Name[sv]=Integrering av VCS
Name[tr]=Sürüm Kontrol Sistemi Bütünleşmesi
Name[ug]=VCS يۈرۈشلەشتۈرۈلۈشى
Name[uk]=Інтеграція з системами керування версіями
Name[x-test]=xxVCS Integrationxx
Name[zh_CN]=VCS 工程集成
Name[zh_TW]=版本控制系統整合
GenericName=VCS Integration
GenericName[bs]=VCS Integracija
GenericName[ca]=Integració de VCS
GenericName[ca@valencia]=Integració de VCS
GenericName[da]=VCS-integration
GenericName[de]=VCS-Integration
GenericName[el]=VCS ολοκλήρωση
GenericName[en_GB]=VCS Integration
GenericName[es]=Integración VCS
GenericName[et]=Versioonihalduse lõimimine
GenericName[fi]=VCS-integraatio
GenericName[fr]=Intégration de VCS
GenericName[gl]=Integración con VCS
GenericName[hu]=VCS integráció
GenericName[it]=Integrazione VCS
GenericName[kk]=Нұсқаларын қадағалау жүйесімен біріктіру 
GenericName[nb]=VCS-integrering
GenericName[nds]=VKS-Inbinnen
GenericName[nl]=VCS-integratie
GenericName[pl]=Integracja VCS
GenericName[pt]=Integração com o SCV
GenericName[pt_BR]=Integração com o VCS
GenericName[ru]=Интеграция VCS
GenericName[sk]=Integrácia VCS
GenericName[sl]=Vgradnja nadzora različic
GenericName[sv]=Integrering av VCS
GenericName[tr]=Sürüm Kontrol Sistemi Bütünleşmesi
GenericName[ug]=VCS يۈرۈشلەشتۈرۈلۈشى
GenericName[uk]=Інтеграція з системами керування версіями
GenericName[x-test]=xxVCS Integrationxx
GenericName[zh_CN]=VCS 工程集成
GenericName[zh_TW]=版本控制系統整合
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevvcschangesviewplugin
X-KDE-PluginInfo-Name=kdevvcschangesviewplugin
X-KDE-PluginInfo-Author=Aleix Pol
X-KDE-PluginInfo-Email=aleixpol@kde.org
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Version Control
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform-1.7.2.tar.xz: kdevplatform-1.7.2/plugins/vcschangesview/kdevvcschangesview.desktop.cmake <==
[Desktop Entry]
Type=Service
Comment=This plugin provides integration between the projects and their VCS infrastructure
Comment[bs]=Ovaj dodatak omogućava integraciju između projekata i njihove VCS infrakstrukture
Comment[ca]=Aquest connector proporciona la integració entre els projectes i la seva infraestructura de VCS
Comment[ca@valencia]=Este connector proporciona la integració entre els projectes i la seua infraestructura de VCS
Comment[da]=Dette plugin giver integration mellem projekterne og deres VCS-infrastruktur
Comment[de]=Dieses Modul stellt eine Integration zwischen Projekten und ihrer VCS-Infrastruktur her.
Comment[el]=Το πρόσθετο αυτό παρέχει ολοκλήρωση ανάμεσα στα έργα και της VCS υποδομής τους
Comment[en_GB]=This plugin provides integration between the projects and their VCS infrastructure
Comment[es]=Este complemento proporciona integración entre los proyectos y su infraestructura VCS
Comment[et]=See plugin võimaldab lõimida projektid ja nende versioonihalduse infrastruktuuri
Comment[fi]=Tämä liitännäinen tarjoaa projektien ja niiden versionhallintajärjestelmien välisen integraation
Comment[fr]=Ce module externe fournit une intégration entre les projets et leur infrastructure VCS
Comment[gl]=Este complemento fornece integración entre os proxectos e a súa infraestrutura VCS
Comment[hu]=Ez a bővítmény integrációt biztosít a projektek és azok VCS infrastruktúrája között
Comment[it]=Questa estensione fornisce integrazione tra i progetti e la loro infrastruttura VCS
Comment[kk]=Бұл плагині жоба мен оның нұсқаларын қадағалау жүйесімен біріктіруін қамтамасыз етеді.
Comment[nb]=Dette programtillegget gir integrering mellom prosjektene og deres VCS infrastruktur
Comment[nds]=Mit dit Moduul laat sik Projekten un ehr VKS-Infrastruktuur inbinnen.
Comment[nl]=Deze plugin geeft integratie tussen de projecten en hun VCS-infrastructuur
Comment[pl]=Wtyczka ta zapewnia integracje pomiędzy projektami i ich infrastrukturą systemu zarządzania wersją (VCS)
Comment[pt]=Este 'plugin' oferece a integração entre os projectos e a sua infra-estrutura de SCV
Comment[pt_BR]=Este plugin fornece a integração entre os projetos e sua infraestrutura de VCS
Comment[ru]=Это расширение обеспечивает интеграцию проектов с инфраструктурой VCS
Comment[sk]=Tento plugin poskytuje integráciu medzi projektami a ich VCS infraštruktúrou
Comment[sl]=Ta vstavek ponuja most med projekti in njihovo infrastrukturo nadzora različic
Comment[sv]=Det här insticksprogrammet tillhandahåller integrering mellan projekten och deras VCS infrastruktur
Comment[tr]=Bu eklenti, projeler ile projelerin sürüm kontrol sistemi altyapıları arasında bütünleşme sağlar
Comment[uk]=Цей додаток забезпечує інтеграцію між проектами та їхньою структурою системи керування версіями
Comment[x-test]=xxThis plugin provides integration between the projects and their VCS infrastructurexx
Comment[zh_CN]=此插件提供工程和它们的代码管理系统的集成
Comment[zh_TW]=此外掛程式提供專案與它們之間版本控制系統基礎間的整合
Name=VCS Integration
Name[bs]=VCS Integracija
Name[ca]=Integració de VCS
Name[ca@valencia]=Integració de VCS
Name[da]=VCS-integration
Name[de]=VCS-Integration
Name[el]=VCS ολοκλήρωση
Name[en_GB]=VCS Integration
Name[es]=Integración VCS
Name[et]=Versioonihalduse lõimimine
Name[fi]=VCS-integraatio
Name[fr]=Intégration de VCS
Name[gl]=Integración con VCS
Name[hu]=VCS integráció
Name[it]=Integrazione VCS
Name[kk]=Нұсқаларын қадағалау жүйесімен біріктіру 
Name[nb]=VCS-integrering
Name[nds]=VKS-Inbinnen
Name[nl]=VCS-integratie
Name[pl]=Integracja VCS
Name[pt]=Integração com o SCV
Name[pt_BR]=Integração com o VCS
Name[ru]=Интеграция VCS
Name[sk]=Integrácia VCS
Name[sl]=Vgradnja nadzora različic
Name[sv]=Integrering av VCS
Name[tr]=Sürüm Kontrol Sistemi Bütünleşmesi
Name[ug]=VCS يۈرۈشلەشتۈرۈلۈشى
Name[uk]=Інтеграція з системами керування версіями
Name[x-test]=xxVCS Integrationxx
Name[zh_CN]=VCS 工程集成
Name[zh_TW]=版本控制系統整合
GenericName=VCS Integration
GenericName[bs]=VCS Integracija
GenericName[ca]=Integració de VCS
GenericName[ca@valencia]=Integració de VCS
GenericName[da]=VCS-integration
GenericName[de]=VCS-Integration
GenericName[el]=VCS ολοκλήρωση
GenericName[en_GB]=VCS Integration
GenericName[es]=Integración VCS
GenericName[et]=Versioonihalduse lõimimine
GenericName[fi]=VCS-integraatio
GenericName[fr]=Intégration de VCS
GenericName[gl]=Integración con VCS
GenericName[hu]=VCS integráció
GenericName[it]=Integrazione VCS
GenericName[kk]=Нұсқаларын қадағалау жүйесімен біріктіру 
GenericName[nb]=VCS-integrering
GenericName[nds]=VKS-Inbinnen
GenericName[nl]=VCS-integratie
GenericName[pl]=Integracja VCS
GenericName[pt]=Integração com o SCV
GenericName[pt_BR]=Integração com o VCS
GenericName[ru]=Интеграция VCS
GenericName[sk]=Integrácia VCS
GenericName[sl]=Vgradnja nadzora različic
GenericName[sv]=Integrering av VCS
GenericName[tr]=Sürüm Kontrol Sistemi Bütünleşmesi
GenericName[ug]=VCS يۈرۈشلەشتۈرۈلۈشى
GenericName[uk]=Інтеграція з системами керування версіями
GenericName[x-test]=xxVCS Integrationxx
GenericName[zh_CN]=VCS 工程集成
GenericName[zh_TW]=版本控制系統整合
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevvcschangesviewplugin
X-KDE-PluginInfo-Name=kdevvcschangesviewplugin
X-KDE-PluginInfo-Author=Aleix Pol
X-KDE-PluginInfo-Email=aleixpol@kde.org
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Version Control
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
